//******************************************************************************
///
/// @file parser/_fnnames.h
///
/// This header file contains static character string arrays used primarily to
/// drive documentation associated with the povr fork of POV-Ray. The arrays are
/// used in the final executable to provide for scene description language (SDL)
/// functions word_is() and word_get(). The active function names array is used
/// with the 'no lower case, user identifier' checking if the executable is
/// compiled with that option (NO_LC_USER_IDENTIFIERS).
///
/// The arrays are maintained in several files in total:
///     _directivewords.h, _fakebyfnctwords.h, _fnnames.h, _keywords.h,
///     _oddwords.h and _optionnames.h.
///
/// @copyright
/// @parblock
///
/// Persistence of Vision Ray Tracer ('POV-Ray') version 3.8.
/// Copyright 1991-2023 Persistence of Vision Raytracer Pty. Ltd.
///
/// POV-Ray is free software: you can redistribute it and/or modify
/// it under the terms of the GNU Affero General Public License as
/// published by the Free Software Foundation, either version 3 of the
/// License, or (at your option) any later version.
///
/// POV-Ray is distributed in the hope that it will be useful,
/// but WITHOUT ANY WARRANTY; without even the implied warranty of
/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/// GNU Affero General Public License for more details.
///
/// You should have received a copy of the GNU Affero General Public License
/// along with this program.  If not, see <http://www.gnu.org/licenses/>.
///
/// ----------------------------------------------------------------------------
///
/// POV-Ray is based on the popular DKB raytracer version 2.12.
/// DKBTrace was originally written by David K. Buck.
/// DKBTrace Ver 2.0-2.12 were written by David K. Buck & Aaron A. Collins.
///
/// @endparblock
///
//------------------------------------------------------------------------------
// SPDX-License-Identifier: AGPL-3.0-or-later
//******************************************************************************

#ifndef POVRAY_PARSER__FNNAMES_H
#define POVRAY_PARSER__FNNAMES_H

static char iFnNames[][26] {"cf_abs", "cf_acos", "cf_acosh", "cf_add", "cf_asin", "cf_asinh", "cf_atan", "cf_atanh",
    "cf_cmplx", "cf_conj", "cf_cos", "cf_cosh", "cf_div", "cf_exp", "cf_imag", "cf_inv", "cf_ln", "cf_log", "cf_mul",
    "cf_neg", "cf_norm", "cf_phase", "cf_polar", "cf_pow", "cf_proj", "cf_real", "cf_sin", "cf_sinh", "cf_sqr",
    "cf_sqrt", "cf_sub", "cf_tan", "cf_tanh", "f_64x_ui1_and", "f_64x_ui1_fltto", "f_64x_ui1_not", "f_64x_ui1_or",
    "f_64x_ui1_popcnt", "f_64x_ui1_shl", "f_64x_ui1_shr", "f_64x_ui1_toflt", "f_64x_ui1_xor", "f_agate", "f_boom",
    "f_box", "f_boxb", "f_bump", "f_cbrt", "f_clock", "f_cone", "f_cubic_wave", "f_cylinder", "f_dec16x_ui4",
    "f_dec2x_f32", "f_dec32x_ui2", "f_dec3x_f21", "f_dec4x_ui16", "f_dec64x_ui1", "f_dec8x_ui8", "f_dec_nbit3c",
    "f_distribution", "f_dturbulence", "f_eblob", "f_ellipsoid", "f_elliptical_cylinder", "f_elliptical_sphrswp",
    "f_enc16x_ui4", "f_enc2x_f32", "f_enc32x_ui2", "f_enc3x_f21", "f_enc4x_ui16", "f_enc64x_ui1", "f_enc8x_ui8",
    "f_enc_nbit3c", "f_gradient", "f_granite23", "f_hash", "f_helix1", "f_helix2", "f_hessian_dist", "f_hetero_mf",
    "f_hypot", "f_interior_fade", "f_labsweep", "f_lame", "f_length", "f_length_sqr", "f_marble", "f_max1to8pairs",
    "f_min1to8pairs", "f_morph2to9fncts", "f_mult1to8pairs", "f_noise3d", "f_noise_cubed", "f_normal", "f_normalized",
    "f_npmod", "f_null", "f_odd", "f_onion", "f_paraboloid", "f_path", "f_ph", "f_planar", "f_polyhedron",
    "f_quartic_cylinder", "f_quilt_cubic", "f_r", "f_radial", "f_radial_tubes", "f_randn", "f_range2range", "f_remap",
    "f_repeat", "f_revolution", "f_ridge", "f_ridged_mf", "f_rotate2d", "f_rounded_box", "f_scallop_wave",
    "f_scallop_wavef", "f_sign", "f_sign0", "f_signpow", "f_signsqrt", "f_sine_wave", "f_sine_wavef", "f_snoise3d",
    "f_sphere", "f_spiral", "f_superellipsoid", "f_supertorus", "f_th", "f_torus", "f_toupie", "f_triangle_wave",
    "f_turbulence", "f_upoly", "f_vangle", "f_wood", "f_wrap"};

static char oFnNames[][26] { "f_algbr_cyl1", "f_algbr_cyl2", "f_algbr_cyl3", "f_algbr_cyl4", "f_bicorn", "f_bifolia",
    "f_blob", "f_blob2", "f_boy_surface", "f_comma", "f_cross_ellipsoids", "f_crossed_trough", "f_cubic_saddle",
    "f_cushion", "f_devils_curve", "f_devils_curve_2d", "f_dupin_cyclid", "f_flange_cover", "f_folium_surface",
    "f_folium_surface_2d", "f_glob", "f_heart", "f_helical_torus", "f_hex_x", "f_hex_y", "f_hunt_surface",
    "f_hyperbolic_torus", "f_isect_ellipsoids", "f_kampyle_of_eudoxus", "f_kampyle_of_eudoxus_2d", "f_klein_bottle",
    "f_kummer_surface_v1", "f_kummer_surface_v2", "f_lemniscate_of_gerono", "f_lemniscate_of_gerono_2d", "f_mesh1",
    "f_mitre", "f_nodal_cubic", "f_noise_generator", "f_ovals_of_cassini", "f_parabolic_torus", "f_pillow",
    "f_piriform", "f_piriform_2d", "f_poly4", "f_polytubes", "f_quantum", "f_quartic_paraboloid", "f_quartic_saddle",
    "f_spikes", "f_spikes_2d", "f_steiners_roman", "f_strophoid", "f_strophoid_2d", "f_torus2", "f_torus_gumdrop",
    "f_umbrella", "f_witch_of_agnesi", "f_witch_of_agnesi_2d"};

static char nFnNames[][26] { "cf_abs", "cf_acos", "cf_acosh", "cf_add", "cf_asin", "cf_asinh", "cf_atan", "cf_atanh",
    "cf_cmplx", "cf_conj", "cf_cos", "cf_cosh", "cf_div", "cf_exp", "cf_imag", "cf_inv", "cf_ln", "cf_log", "cf_mul",
    "cf_neg", "cf_norm", "cf_phase", "cf_polar", "cf_pow", "cf_proj", "cf_real", "cf_sin", "cf_sinh", "cf_sqr",
    "cf_sqrt", "cf_sub", "cf_tan", "cf_tanh", "f_64x_ui1_and", "f_64x_ui1_fltto", "f_64x_ui1_not", "f_64x_ui1_or",
    "f_64x_ui1_popcnt", "f_64x_ui1_shl", "f_64x_ui1_shr", "f_64x_ui1_toflt", "f_64x_ui1_xor", "f_agate", "f_boom",
    "f_box", "f_boxb", "f_bump", "f_cbrt", "f_clock", "f_cone", "f_cubic_wave", "f_cylinder", "f_dec16x_ui4",
    "f_dec2x_f32", "f_dec32x_ui2", "f_dec3x_f21", "f_enc4x_ui16", "f_dec64x_ui1", "f_dec8x_ui8", "f_dec_nbit3c",
    "f_distribution", "f_dturbulence", "f_eblob", "f_elliptical_cylinder", "f_elliptical_sphrswp", "f_enc16x_ui4",
    "f_enc2x_f32", "f_enc32x_ui2", "f_enc3x_f21", "f_enc4x_ui16", "f_enc64x_ui1", "f_enc8x_ui8", "f_enc_nbit3c",
    "f_gradient", "f_granite23", "f_hash", "f_hessian_dist", "f_hypot", "f_interior_fade", "f_labsweep", "f_lame",
    "f_length", "f_length_sqr", "f_marble", "f_max1to8pairs", "f_min1to8pairs", "f_morph2to9fncts", "f_mult1to8pairs",
    "f_noise_cubed", "f_normal", "f_normalized", "f_npmod", "f_null", "f_onion", "f_path", "f_planar", "f_polyhedron",
    "f_quilt_cubic", "f_radial", "f_radial_tubes", "f_randn", "f_range2range", "f_remap", "f_repeat", "f_revolution",
    "f_rotate2d", "f_scallop_wave", "f_scallop_wavef", "f_sign", "f_sign0", "f_signpow", "f_signsqrt", "f_sine_wave",
    "f_sine_wavef", "f_snoise3d", "f_supertorus", "f_toupie", "f_triangle_wave", "f_turbulence", "f_upoly", "f_vangle",
    "f_wood", "f_wrap"};

#endif // POVRAY_PARSER__FNNAMES_H
